# Analysis of A. maculatum data using permutation and resampling methods
require(reshape)
require(exactRankTests)
require(coin)

#Read data
dist <- read.csv("Pond_Dist.csv")[,3]
am<-read.csv("amac_data.csv",header=T,sep=",")

am.long <- melt(am,id=c("pond","measure"),variable_name="stage")

# ANOVA data
am.rich<-am.long[which(am.long$measure=="a.rich"),]
am.Fst<-am.long[which(am.long$measure=="Fst"),]
am.Dc<-am.long[which(am.long$measure=="Dc"),]
am.He<-am.long[which(am.long$measure=="He"),]
am.Ne<-am.long[which(am.long$measure=="Ne"),]
am.priv<-am.long[which(am.long$measure=="private"),]
am.remove<-am.long[which(am.long$measure=="samples.removed"),]

# Make list of ANOVA dataframes
AM.df<-c("am.rich","am.Fst","as.Dc","am.He","am.Ne","am.priv","am.remove")
AM.list<-list(am.rich,am.Fst,am.Dc,am.He,am.Ne,am.priv,am.remove)
DFs<-length(AM.df)

# Assess boxplots
for (i in 1:DFs){
  df<-AM.list[[i]]
  boxplot(value~stage,data=df,main=AM.df[i])
}

####

# Bootstrap each ANOVA analysis
R<-50000 # Number of iterations
Boot.ANOVA<-data.frame()
system.time(for (i in 1:DFs){
  df<-AM.list[[i]]
  df<-na.omit(df)
  
  Fstat<-oneway.test(value~stage,data=df)$statistic
  ORIG.TEST<-aov(value~stage,data=df)
  Fstat<-summary(ORIG.TEST)[[1]][["F value"]]
  
  meanstar = with(df, tapply(value,stage,mean,na.rm=T))
  adult = df$value[df$stage=="adult"] - meanstar[1]
  embryo = df$value[df$stage=="embryo"] - meanstar[2]
  larvae = df$value[df$stage=="larvae"] - meanstar[3]  
  
  sim.data = df$stage
  
  Fstar<-numeric(R)
  for (j in 1:R) {   
    ADULT = sample(adult, size=length(adult), replace=T)
    EMBRYO = sample(embryo, size=length(embryo), replace=T)
    LARVAE = sample(larvae, size=length(larvae), replace=T)
    
    simcount = c(ADULT,EMBRYO,LARVAE)
    simdata = data.frame(simcount,sim.data)
    Fstar[j] = oneway.test(simcount~sim.data, var.equal=T, data=simdata)$statistic
    Crit.F<-quantile(Fstar,.95)
    p.val<-1-(ecdf(Fstar)(Fstat[1]))
  }
  Boot.ANOVA[i,1]<-AM.df[[i]]
  Boot.ANOVA[i,2]<-Crit.F
  Boot.ANOVA[i,3]<-Fstat[1]
  Boot.ANOVA[i,4]<-p.val
})  
 
  colnames(Boot.ANOVA)<-c("Measure","Critical F","Model F", "p-value")
  (Boot.ANOVA)

###########################

# Adult-Embryo t-test data
ae.rich<-am.rich[,3:4]
ae.Fst<-am.Fst[,3:4]
ae.Dc<-am.Dc[,3:4]
ae.He<-am.He[,3:4]
ae.Ne<-am.Ne[,3:4]
ae.priv<-am.priv[,3:4]
ae.remove<-am.remove[,3:4]

# Make list of A-E dataframes
AE.df<-c("ae.rich","ae.Fst","ae.Dc","ae.He","ae.Ne","ae.priv","ae.remove")
AE.list<-list(ae.rich,ae.Fst,ae.Dc,ae.He,ae.Ne,ae.priv,ae.remove)

#Adult-Embryo with Larvae t-test data
ael.rich<-am[which(am$measure=="a.rich"&am$larvae!="NA"),]
ael.Fst<-am[which(am$measure=="Fst"&am$larvae!="NA"),]
ael.Dc<-am[which(am$measure=="Dc"&am$larvae!="NA"),]
ael.He<-am[which(am$measure=="He"&am$larvae!="NA"),]
ael.Ne<-am[which(am$measure=="Ne"&am$larvae!="NA"),]
ael.priv<-am[which(am$measure=="private"&am$larvae!="NA"),]
ael.remove<-am[which(am$measure=="samples.removed"&am$larvae!="NA"),]

# Make list of A-E-L dataframes
AEL.df<-list("ael.rich","ael.Fst","ael.Dc","ael.He","ael.Ne","ael.priv","ael.remove")
AEL.list<-list(ael.rich,ael.Fst,ael.Dc,ael.He,ael.Ne,ael.priv,ael.remove)


##############
# Permutation tests for paired t-tests
require("exactRankTests")

# ADULT-LARVAE
DFs<-length(AEL.df)
AL_Results<-data.frame()

for (i in 1:DFs){
  data.set<-AEL.df[[i]]
  df<-AEL.list[[i]]
  PERM.TEST<-perm.test(df$adult,y=df$larvae,paired=T,exact=T)
  p.val<-PERM.TEST$p.value
  AL_Results[i,1]<-data.set
  AL_Results[i,2]<-p.val
}
colnames(AL_Results)<-c("measure","p.value")
AL_Results

# EMBRYO-LARVAE
DFs<-length(AEL.df)
EL_Results<-data.frame()

for (i in 1:DFs){
  data.set<-AEL.df[[i]]
  df<-AEL.list[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  EL_Results[i,1]<-data.set
  EL_Results[i,2]<-p.val
}
colnames(EL_Results)<-c("measure","p.value")
EL_Results

# ADULT-EMBRYO
DFs<-length(AE.df)
AE_Results<-data.frame()

for (i in 1:DFs){
  data.set<-AE.df[[i]]
  df<-AEL.list[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  AE_Results[i,1]<-data.set
  AE_Results[i,2]<-p.val
}
colnames(AE_Results)<-c("measure","p.value")
AE_Results

#####

#Read data that includes siblings
am2<-read.csv("amac_data_all.csv",header=T,sep=",")

am.long <- melt(am2,id=c("pond","measure"),variable_name="stage")

# ANOVA data
am.rich2<-am.long[which(am.long$measure=="a.rich"),]
am.Fst2<-am.long[which(am.long$measure=="Fst"),]
am.Dc2<-am.long[which(am.long$measure=="Dc"),]
am.He2<-am.long[which(am.long$measure=="He"),]

# Make list of ANOVA dataframes
AM.df2<-c("am.rich2","am.Fst2","am.Dc2","am.He2")
AM.list2<-list(am.rich,am.Fst,am.Dc,am.He)
DFs2<-length(AM.df2)

# Assess boxplots
for (i in 1:DFs2){
  df<-AM.list2[[i]]
  boxplot(value~stage,data=df,main=AM.df2[i])
}

# Bootstrap each ANOVA analysis
R<-50000 # Number of iterations
Boot.ANOVA2<-data.frame()
system.time(for (i in 1:DFs2){
  df<-AM.list2[[i]]
  df<-na.omit(df)
  
  Fstat<-oneway.test(value~stage,data=df)$statistic
  ORIG.TEST<-aov(value~stage,data=df)
  Fstat<-summary(ORIG.TEST)[[1]][["F value"]]
  
  meanstar = with(df, tapply(value,stage,mean,na.rm=T))
  adult = df$value[df$stage=="adult"] - meanstar[1]
  embryo = df$value[df$stage=="embryo"] - meanstar[2]
  larvae = df$value[df$stage=="larvae"] - meanstar[3]  
  
  sim.data = df$stage
  
  Fstar<-numeric(R)
  for (j in 1:R) {   
    ADULT = sample(adult, size=length(adult), replace=T)
    EMBRYO = sample(embryo, size=length(embryo), replace=T)
    LARVAE = sample(larvae, size=length(larvae), replace=T)
    
    simcount = c(ADULT,EMBRYO,LARVAE)
    simdata = data.frame(simcount,sim.data)
    Fstar[j] = oneway.test(simcount~sim.data, var.equal=T, data=simdata)$statistic
    Crit.F<-quantile(Fstar,.95)
    p.val<-1-(ecdf(Fstar)(Fstat[1]))
  }
  Boot.ANOVA2[i,1]<-AM.df[[i]]
  Boot.ANOVA2[i,2]<-Crit.F
  Boot.ANOVA2[i,3]<-Fstat[1]
  Boot.ANOVA2[i,4]<-p.val
})  

colnames(Boot.ANOVA2)<-c("Measure","Critical F","Model F", "p-value")
(Boot.ANOVA2)

###########################
# Adult-Embryo t-test data
ae.rich2<-am.rich2[,3:4]
ae.Fst2<-am.Fst2[,3:4]
ae.Dc2<-am.Dc2[,3:4]
ae.He2<-am.He2[,3:4]

# Make list of A-E dataframes
AE.df2<-c("ae.rich2","ae.Fst2","ae.Dc2","ae.He2")
AE.list2<-list(ae.rich,ae.Fst,ae.Dc,ae.He)

#Adult-Embryo with Larvae t-test data
ael.rich<-am2[which(am2$measure=="a.rich"&am2$larvae!="NA"),]
ael.Fst<-am2[which(am2$measure=="Fst"&am2$larvae!="NA"),]
ael.Dc<-am2[which(am2$measure=="Dc"&am2$larvae!="NA"),]
ael.He<-am2[which(am2$measure=="He"&am2$larvae!="NA"),]

# Make list of A-E-L dataframes
AEL.df2<-list("ael.rich","ael.Fst","ael.Dc","ael.He")
AEL.list2<-list(ael.rich,ael.Fst,ael.Dc,ael.He)

##############
# Permutation tests for paired t-tests
require("exactRankTests")

# ADULT-LARVAE
DFs2<-length(AEL.df2)
AL_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AEL.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(df$adult,y=df$larvae,paired=T,exact=T)
  p.val<-PERM.TEST$p.value
  AL_Results2[i,1]<-data.set
  AL_Results2[i,2]<-p.val
}
colnames(AL_Results2)<-c("measure","p.value")
AL_Results2

# EMBRYO-LARVAE
DFs2<-length(AEL.df2)
EL_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AEL.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  EL_Results2[i,1]<-data.set
  EL_Results2[i,2]<-p.val
}
colnames(EL_Results2)<-c("measure","p.value")
EL_Results2

# ADULT-EMBRYO
DFs2<-length(AE.df2)
AE_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AE.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  AE_Results2[i,1]<-data.set
  AE_Results2[i,2]<-p.val
}
colnames(AE_Results2)<-c("measure","p.value")
AE_Results2
#############################
#############################
#############################

# Effects of sibling removal
# Adult-Embryo t-test data
ae.rich3<-cbind(am.rich[,3:4],am.rich2[,3:4])
ae.Fst3<-cbind(am.Fst[,3:4],am.Fst2[,3:4])
ae.Dc3<-cbind(am.Dc[,3:4],am.Dc2[,3:4])
ae.He3<-cbind(am.He[,3:4],am.He2[,3:4])

# Make list of A-E dataframes
AE.df2<-c("ae.rich2","ae.Fst2","ae.He2")
AE.list2<-list(ae.rich,ae.Fst,ae.Dc,ae.He)

#Adult-Embryo with Larvae t-test data
ael.rich<-am2[which(am2$measure=="a.rich"&am2$larvae!="NA"),]
ael.Fst<-am2[which(am2$measure=="Fst"&am2$larvae!="NA"),]
ael.Dc<-am2[which(am2$measure=="Dc"&am2$larvae!="NA"),]
ael.He<-am2[which(am2$measure=="He"&am2$larvae!="NA"),]

AEL.df2<-list("ael.rich","ael.Fst","ael.Dc","ael.He")
AEL.list2<-list(ael.rich,ael.Fst,ael.Dc,ael.He)

##############
# Permutation tests for paired t-tests
require("exactRankTests")

# ADULT-LARVAE
DFs2<-length(AEL.df2)
AL_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AEL.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(df$adult,y=df$larvae,paired=T,exact=T)
  #   Ind.TEST<-independence_test(adult~larvae,data=df,distribution="exact",alternative="two.sided")
  p.val<-PERM.TEST$p.value
  AL_Results2[i,1]<-data.set
  AL_Results2[i,2]<-p.val
}
colnames(AL_Results2)<-c("measure","p.value")
AL_Results2

# EMBRYO-LARVAE
DFs2<-length(AEL.df2)
EL_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AEL.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  EL_Results2[i,1]<-data.set
  EL_Results2[i,2]<-p.val
}
colnames(EL_Results2)<-c("measure","p.value")
EL_Results2

# ADULT-EMBRYO
DFs2<-length(AE.df2)
AE_Results2<-data.frame()

for (i in 1:DFs2){
  data.set<-AE.df2[[i]]
  df<-AEL.list2[[i]]
  PERM.TEST<-perm.test(x=df$embryo,y=df$larvae,paired=TRUE,exact=TRUE)
  p.val<-PERM.TEST$p.value
  AE_Results2[i,1]<-data.set
  AE_Results2[i,2]<-p.val
}
colnames(AE_Results2)<-c("measure","p.value")
AE_Results2

#######
